/** RPM SQL Upgrade Script - Version 6.0.6 to Version 6.0.7 **/
/** Run this script for each of your RPM SQL databases **/
/** Change the database name below - RPMDB - to the name of your actual RPM database before running the script **/
/** Click Execute to run the script **/

USE RPMDB 
GO

-- 5844
ALTER TABLE [System] Alter Column [PaymentMethodDefault] nvarchar(20) Null
GO
UPDATE [System] Set PaymentMethodDefault = RTrim(PaymentMethodDefault)
GO

--5068
Alter table [TransType] Disable trigger all
GO
Alter Table [TransType] Add [Inactive] [bit] NULL
GO
UPDATE [TransType] SET [Inactive] = 0
GO
ALTER TABLE [dbo].[TransType] ADD 
	CONSTRAINT [DF_TransType_Inactive] DEFAULT (0) FOR [Inactive]
GO
ALTER TABLE [TransType] Alter Column [Inactive] [bit] NOT NULL
GO
Alter table [TransType] Enable trigger all
GO

CREATE View [dbo].[vwSchdTransferActive] As
SELECT SchedTransfer.*, Client.ClientNameFL as ToClientNameFL, Client_1.ClientNameFL as FromClientNameFL
FROM (((((SchedTransfer INNER JOIN Client ON SchedTransfer.FromClientID = Client.ClientId) INNER JOIN Client AS Client_1 ON SchedTransfer.ToClientID = Client_1.ClientId) 
INNER JOIN ClientAccount ON (SchedTransfer.FromAccountID = ClientAccount.AccountID) AND (SchedTransfer.FromClientID = ClientAccount.ClientID)) 
INNER JOIN ClientAccount AS ClientAccount_1 ON (SchedTransfer.ToAccountID = ClientAccount_1.AccountID) AND (SchedTransfer.ToClientID = ClientAccount_1.ClientID)) 
INNER JOIN AccountList ON ClientAccount.AccountID = AccountList.AccountID) INNER JOIN AccountList AS AccountList_1 ON ClientAccount_1.AccountID = AccountList_1.AccountID
WHERE (((SchedTransfer.NextTransferDate) Is Not Null) AND ((Client.StatusType)='Active') AND ((Client_1.StatusType)='Active') AND ((ClientAccount.InactiveAcct)=0) 
AND ((AccountList.InactiveMass)=0) AND ((ClientAccount_1.InactiveAcct)=0) AND ((AccountList_1.InactiveMass)=0));
GO

-- 5811
ALTER TABLE Client ADD Pronoun nvarchar(25) Null
GO

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [dbo].[PronounList](
	[Pronoun] [nvarchar](25) NOT NULL,
 CONSTRAINT [PK_Pronoun] PRIMARY KEY CLUSTERED 
(
	[Pronoun] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]

GO

CREATE NONCLUSTERED INDEX [ClientPronoun] ON [dbo].[Client]
(
	[Pronoun] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
ALTER TABLE [dbo].[Client]  WITH CHECK ADD  CONSTRAINT [ClientPronoun_FK00] FOREIGN KEY([Pronoun])
REFERENCES [dbo].[PronounList] ([Pronoun])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[Client] CHECK CONSTRAINT [ClientPronoun_FK00]
GO

-- 5854
ALTER Table [Client] Alter Column Gender nvarchar(25) Null
GO
DELETE FROM GenderList Where GenderDescription Is Null
GO
ALTER Table [GenderList] Alter Column GenderDescription nvarchar(25) Not Null
GO

UPDATE Client SET Client.Gender = GenderList.GenderDescription FROM Client INNER JOIN GenderList ON Client.Gender = GenderList.GenderType 
GO
UPDATE Client SET Client.Gender = Null FROM Client LEFT JOIN GenderList ON Client.Gender = GenderList.GenderDescription 
WHERE Client.Gender Is Not Null and GenderList.GenderDescription Is Null
GO

DROP INDEX GenderType on GenderList
GO
ALTER Table [GenderList] Drop Column [GenderType]
GO
ALTER TABLE [GenderList] Drop Constraint aaaaaGenderList_PK
GO
ALTER Table [GenderList] Drop Column [GenderListID]
GO
ALTER TABLE [GenderList] Add Constraint PK_GenderDescription Primary Key (GenderDescription)
GO

CREATE NONCLUSTERED INDEX [ClientGender] ON [dbo].[Client]
(
	[Gender] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
ALTER TABLE [dbo].[Client]  WITH CHECK ADD  CONSTRAINT [ClientGender_FK00] FOREIGN KEY([Gender])
REFERENCES [dbo].[GenderList] ([GenderDescription])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[Client] CHECK CONSTRAINT [ClientGender_FK00]
GO

-- 5563
ALTER Table [Housing] Add [Address] nvarchar(50) NULL
ALTER Table [Housing] Add [City] nvarchar(50) NULL
ALTER Table [Housing] Add [State] nvarchar(2) NULL
ALTER Table [Housing] Add [Zip] nvarchar(12) NULL
ALTER Table [Housing] Add [HousingNote] varchar(max) Null

-- 5879
INSERT INTO UserSecurity ( UserID, SecurityLevel, ObjectID ) SELECT UserSecurity.UserID, UserSecurity.SecurityLevel, 104 FROM UserSecurity WHERE UserSecurity.ObjectID = 6
GO

-- 5395
Alter Table [CheckLayout] Add [MailToUpper] [bit] NULL
GO
UPDATE CheckLayout SET CheckLayout.MailToUpper = 0
GO
ALTER TABLE [dbo].[CheckLayout] ADD 
	CONSTRAINT [DF_CheckLayout_MailToUpper] DEFAULT (0) FOR [MailToUpper]
GO
ALTER TABLE [CheckLayout] Alter Column [MailToUpper] [bit] NOT NULL
GO

-- 5881
ALTER TABLE Client ADD CustomList8 nvarchar(50) Null
GO
ALTER TABLE Client ADD CustomList9 nvarchar(50) Null
GO
ALTER TABLE Client ADD CustomList10 nvarchar(50) Null
GO
Alter Table Client Add CustomField8 nvarchar(50) Null
GO
Alter Table Client Add CustomField9 nvarchar(50) Null
GO
Alter Table Client Add CustomField10 nvarchar(50) Null
GO
/****** Object:  Table [dbo].[CustomList8] ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CustomList8](
	[CustomList8] [nvarchar](50) NOT NULL,
 CONSTRAINT [PK_CustomList8] PRIMARY KEY CLUSTERED 
(
	[CustomList8] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[CustomList9] ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CustomList9](
	[CustomList9] [nvarchar](50) NOT NULL,
 CONSTRAINT [PK_CustomList9] PRIMARY KEY CLUSTERED 
(
	[CustomList9] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[CustomList10] ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CustomList10](
	[CustomList10] [nvarchar](50) NOT NULL,
 CONSTRAINT [PK_CustomList10] PRIMARY KEY CLUSTERED 
(
	[CustomList10] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO

Alter Table [System] Add CustomField8Active Bit Null
GO
Alter Table [System] Add CustomField8Label nvarchar(30)
GO
Alter Table [System] Add CustomField9Active Bit Null
GO
Alter Table [System] Add CustomField9Label nvarchar(30)
GO
Alter Table [System] Add CustomField10Active Bit Null
GO
Alter Table [System] Add CustomField10Label nvarchar(30)
GO
Alter Table [System] Add CustomList8Active Bit Null
GO
Alter Table [System] Add CustomList8Label nvarchar(30)
GO
Alter Table [System] Add CustomList9Active Bit Null
GO
Alter Table [System] Add CustomList9Label nvarchar(30)
GO
Alter Table [System] Add CustomList10Active Bit Null
GO
Alter Table [System] Add CustomList10Label nvarchar(30)
GO

Update [System] Set CustomList8Active = 0,  CustomList9Active = 0,  CustomList10Active = 0,
	CustomField8Active = 0, CustomField9Active = 0, CustomField10Active = 0
GO

/****** Object:  Index [ClientCustomList8] ******/
CREATE NONCLUSTERED INDEX [ClientCustomList8] ON [dbo].[Client]
(
	[CustomList8] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
ALTER TABLE [dbo].[Client]  WITH CHECK ADD  CONSTRAINT [ClientCustomList8_FK00] FOREIGN KEY([CustomList8])
REFERENCES [dbo].[CustomList8] ([CustomList8])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[Client] CHECK CONSTRAINT [ClientCustomList8_FK00]
GO
/****** Object:  Index [ClientCustomList9] ******/
CREATE NONCLUSTERED INDEX [ClientCustomList9] ON [dbo].[Client]
(
	[CustomList9] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
ALTER TABLE [dbo].[Client]  WITH CHECK ADD  CONSTRAINT [ClientCustomList9_FK00] FOREIGN KEY([CustomList9])
REFERENCES [dbo].[CustomList9] ([CustomList9])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[Client] CHECK CONSTRAINT [ClientCustomList9_FK00]
GO
/****** Object:  Index [ClientCustomList10] ******/
CREATE NONCLUSTERED INDEX [ClientCustomList10] ON [dbo].[Client]
(
	[CustomList10] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
ALTER TABLE [dbo].[Client]  WITH CHECK ADD  CONSTRAINT [ClientCustomList10_FK00] FOREIGN KEY([CustomList10])
REFERENCES [dbo].[CustomList10] ([CustomList10])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[Client] CHECK CONSTRAINT [ClientCustomList10_FK00]
GO

--5825
Alter Table [Transaction] Add [ExclCheckNum] datetime Null
Alter Table [AccountList] Add [Reset] [bit] NULL
GO
UPDATE [AccountList] SET [Reset] = 0
GO
ALTER TABLE [dbo].[AccountList] ADD 
	CONSTRAINT [DF_TransType_Reset] DEFAULT (0) FOR [Reset]
GO

-- 5894
Alter Table [Housing] Add [EndDate] datetime Null
GO

-- 5619
CREATE TABLE [dbo].[Employment](
	[EmploymentID] [int] IDENTITY(1,1) NOT NULL,
	[ClientID] [int] NULL,
	[StartDate] [datetime] NULL,
	[EndDate] [datetime] NULL,
	[EmploymentDesc] [nvarchar](50) NULL,
	[EmploymentNote] [ntext] NULL,
 CONSTRAINT [aaaaaEmployment_PK] PRIMARY KEY NONCLUSTERED 
(
	[EmploymentID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

CREATE NONCLUSTERED INDEX [EmploymentClientID] ON [dbo].[Employment]
(
	[ClientID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO

ALTER TABLE [dbo].[Employment]  WITH CHECK ADD  CONSTRAINT [EmploymentClientID_FK00] FOREIGN KEY([ClientID])
REFERENCES [dbo].[Client] ([ClientId])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[Employment] CHECK CONSTRAINT [EmploymentClientID_FK00]
GO

-- 5707
CREATE TABLE [dbo].[Roommate](
	[RoommateID] [int] IDENTITY(1,1) NOT NULL,
	[ClientID] [int] NULL,
	[RoommateName] [nvarchar](50) NULL,
	[ContactName] [nvarchar](50) NULL,
	[EmailAddress] [nvarchar](50) NULL,
	[RoommateNote] [ntext] NULL,
 CONSTRAINT [aaaaaRoommate_PK] PRIMARY KEY NONCLUSTERED 
(
	[RoommateID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

CREATE NONCLUSTERED INDEX [RoommateClientID] ON [dbo].[Roommate]
(
	[ClientID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO

ALTER TABLE [dbo].[Roommate]  WITH CHECK ADD  CONSTRAINT [RoommateClientID_FK00] FOREIGN KEY([ClientID])
REFERENCES [dbo].[Client] ([ClientId])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[Roommate] CHECK CONSTRAINT [RoommateClientID_FK00]
GO

-- 5431
ALTER TABLE [Asset] ADD [LastUpdated] [datetime] NULL
ALTER TABLE [ClientDocuments] ADD [LastUpdated] [datetime] NULL
ALTER TABLE [ClientContacts] ADD [UserID] [nvarchar](20) NULL
ALTER TABLE [ClientContacts] ADD [LastUpdated] [datetime] NULL
ALTER TABLE [Employment] ADD [UserID] [nvarchar](20) NULL
ALTER TABLE [Employment] ADD [LastUpdated] [datetime] NULL
ALTER TABLE [Events] ADD [UserID] [nvarchar](20) NULL
ALTER TABLE [Events] ADD [LastUpdated] [datetime] NULL
ALTER TABLE [Housing] ADD [UserID] [nvarchar](20) NULL
ALTER TABLE [Housing] ADD [LastUpdated] [datetime] NULL
ALTER TABLE [Impairments] ADD [UserID] [nvarchar](20) NULL
ALTER TABLE [Impairments] ADD [LastUpdated] [datetime] NULL
ALTER TABLE [Income] ADD [UserID] [nvarchar](20) NULL
ALTER TABLE [Income] ADD [LastUpdated] [datetime] NULL
ALTER TABLE [Roommate] ADD [UserID] [nvarchar](20) NULL
ALTER TABLE [Roommate] ADD [LastUpdated] [datetime] NULL
GO

--4970
DELETE SchedTransfer
FROM SchedTransfer LEFT JOIN AccountList ON SchedTransfer.FromAccountID = AccountList.AccountID
WHERE (((AccountList.AccountID) Is Null));

DELETE SchedTransfer
FROM SchedTransfer LEFT JOIN AccountList ON SchedTransfer.ToAccountID = AccountList.AccountID
WHERE (((AccountList.AccountID) Is Null));

-- TransType - Update
DROP TRIGGER [T_TRANSTYPE_UTrig]
DROP TRIGGER [T_TRANSTYPE_DTrig]
GO

ALTER TABLE [dbo].[Transaction] DROP CONSTRAINT [Transaction_FK00]
ALTER TABLE [dbo].[Transaction]  WITH CHECK ADD  CONSTRAINT [TransactionTransType_FK00] FOREIGN KEY([TransType])
REFERENCES [dbo].[TransType] ([TransType])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[Transaction] CHECK CONSTRAINT [TransactionTransType_FK00]
GO

ALTER TABLE [dbo].[AuthPayment] DROP CONSTRAINT [AuthPayment_FK01]
ALTER TABLE [dbo].[AuthPayment]  WITH CHECK ADD  CONSTRAINT [AuthPaymentTransType_FK00] FOREIGN KEY([TransType])
REFERENCES [dbo].[TransType] ([TransType])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[AuthPayment] CHECK CONSTRAINT [AuthPaymentTransType_FK00]
GO

ALTER TABLE [dbo].[SchedDeposit] DROP CONSTRAINT [SchedDeposit_FK01]
ALTER TABLE [dbo].[SchedDeposit]  WITH CHECK ADD  CONSTRAINT [SchedDepositTransType_FK00] FOREIGN KEY([TransType])
REFERENCES [dbo].[TransType] ([TransType])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[SchedDeposit] CHECK CONSTRAINT [SchedDepositTransType_FK00]
GO

ALTER TABLE [dbo].[SchedTransfer] DROP CONSTRAINT [SchedTransfer_FK01]
ALTER TABLE [dbo].[SchedTransfer]  WITH CHECK ADD  CONSTRAINT [SchedTransferTransType_FK00] FOREIGN KEY([TransType])
REFERENCES [dbo].[TransType] ([TransType])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[SchedTransfer] CHECK CONSTRAINT [SchedTransferTransType_FK00]
GO

ALTER TABLE [dbo].[ACHImportConfiguration]  WITH CHECK ADD  CONSTRAINT [ACHImportConfigurationTransType_FK00] FOREIGN KEY([TransType])
REFERENCES [dbo].[TransType] ([TransType])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[ACHImportConfiguration] CHECK CONSTRAINT [ACHImportConfigurationTransType_FK00]
GO

-- AccountList
DROP TRIGGER [T_AccountList_UTrig]
DROP TRIGGER [T_AccountList_DTrig]

ALTER TABLE [dbo].[Transaction] DROP CONSTRAINT [Transaction_FK02]
ALTER TABLE [dbo].[Transaction]  WITH CHECK ADD  CONSTRAINT [TransactionAccountID_FK00] FOREIGN KEY([AccountID])
REFERENCES [dbo].[AccountList] ([AccountID])
GO
ALTER TABLE [dbo].[Transaction] CHECK CONSTRAINT [TransactionAccountID_FK00]
GO

ALTER TABLE [dbo].[ClientAccount] DROP CONSTRAINT [ClientAccount_FK00]
ALTER TABLE [dbo].[ClientAccount]  WITH CHECK ADD  CONSTRAINT [ClientAccountAccountID_FK00] FOREIGN KEY([AccountID])
REFERENCES [dbo].[AccountList] ([AccountID])
GO
ALTER TABLE [dbo].[ClientAccount] CHECK CONSTRAINT [ClientAccountAccountID_FK00]
GO

ALTER TABLE [dbo].[AuthPayment]  WITH CHECK ADD  CONSTRAINT [AuthPaymentAccountID_FK00] FOREIGN KEY([AccountID])
REFERENCES [dbo].[AccountList] ([AccountID])
GO
ALTER TABLE [dbo].[AuthPayment] CHECK CONSTRAINT [AuthPaymentAccountID_FK00]
GO

ALTER TABLE [dbo].[SchedDeposit]  WITH CHECK ADD  CONSTRAINT [SchedDepositAccountID_FK00] FOREIGN KEY([AccountID])
REFERENCES [dbo].[AccountList] ([AccountID])
GO
ALTER TABLE [dbo].[SchedDeposit] CHECK CONSTRAINT [SchedDepositAccountID_FK00]
GO

ALTER TABLE [dbo].[SchedTransfer]  WITH CHECK ADD  CONSTRAINT [SchedTransferFromAccountID_FK00] FOREIGN KEY([FromAccountID])
REFERENCES [dbo].[AccountList] ([AccountID])
GO
ALTER TABLE [dbo].[SchedTransfer] CHECK CONSTRAINT [SchedTransferFromAccountID_FK00]
GO

ALTER TABLE [dbo].[SchedTransfer]  WITH CHECK ADD  CONSTRAINT [SchedTransferToAccountID_FK00] FOREIGN KEY([ToAccountID])
REFERENCES [dbo].[AccountList] ([AccountID])
GO
ALTER TABLE [dbo].[SchedTransfer] CHECK CONSTRAINT [SchedTransferToAccountID_FK00]
GO

-- AssetType - Update
DROP TRIGGER [T_AssetType_UTrig]
DROP TRIGGER [T_AssetType_DTrig]
ALTER TABLE [dbo].[Asset] DROP CONSTRAINT [Asset_FK00]
GO
ALTER TABLE [dbo].[Asset]  WITH CHECK ADD  CONSTRAINT [AssetAssetType_FK00] FOREIGN KEY([AssetType])
REFERENCES [dbo].[AssetType] ([AssetType])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[Asset] CHECK CONSTRAINT [AssetAssetType_FK00]
GO

-- BankList
DROP TRIGGER [T_BankList_UTrig]
DROP TRIGGER [T_BankList_DTrig]
ALTER TABLE [dbo].[AccountList] DROP CONSTRAINT [AccountList_FK00]
ALTER TABLE [dbo].[AccountList]  WITH CHECK ADD  CONSTRAINT [AccountListBankID_FK00] FOREIGN KEY([BankID])
REFERENCES [dbo].[BankList] ([BankID])
GO
ALTER TABLE [dbo].[AccountList] CHECK CONSTRAINT [AccountListBankID_FK00]
GO

-- StatusType - Update
DROP TRIGGER [T_StatusType_UTrig]
DROP TRIGGER [T_StatusType_DTrig]
ALTER TABLE [dbo].[Client] DROP CONSTRAINT [Client_FK06]
GO
ALTER TABLE [dbo].[Client]  WITH CHECK ADD  CONSTRAINT [ClientStatusType_FK00] FOREIGN KEY([StatusType])
REFERENCES [dbo].[StatusType] ([StatusType])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[Client] CHECK CONSTRAINT [ClientStatusType_FK00]
GO

-- Client - Delete
DROP TRIGGER [T_Client_UTrig]
DROP TRIGGER [T_Client_DTrig]
DROP TRIGGER [T_Client_ITrig]

DROP TRIGGER [T_Asset_ITrig]
DROP TRIGGER [T_Asset_UTrig]
ALTER TABLE [dbo].[Asset] DROP CONSTRAINT [Asset_FK01]
ALTER TABLE [dbo].[Asset]  WITH CHECK ADD  CONSTRAINT [AssetClientID_FK00] FOREIGN KEY([ClientID])
REFERENCES [dbo].[Client] ([ClientID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[Asset] CHECK CONSTRAINT [AssetClientID_FK00]
GO

DROP TRIGGER [T_AuthPayment_ITrig]
DROP TRIGGER [T_AuthPayment_UTrig]
ALTER TABLE [dbo].[AuthPayment] DROP CONSTRAINT [AuthPayment_FK00]
ALTER TABLE [dbo].[AuthPayment]  WITH CHECK ADD  CONSTRAINT [AuthPaymentClientID_FK00] FOREIGN KEY([ClientID])
REFERENCES [dbo].[Client] ([ClientID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[AuthPayment] CHECK CONSTRAINT [AuthPaymentClientID_FK00]
GO

DROP TRIGGER [T_CaseNotes_ITrig]
DROP TRIGGER [T_CaseNotes_UTrig]
ALTER TABLE [dbo].[CaseNotes] DROP CONSTRAINT [CaseNotes_FK00]
ALTER TABLE [dbo].[CaseNotes]  WITH CHECK ADD  CONSTRAINT [CaseNotesClientID_FK00] FOREIGN KEY([ClientID])
REFERENCES [dbo].[Client] ([ClientID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[CaseNotes] CHECK CONSTRAINT [CaseNotesClientID_FK00]
GO

DROP TRIGGER [T_ClientAccount_ITrig]
DROP TRIGGER [T_ClientAccount_UTrig]
ALTER TABLE [dbo].[ClientAccount] DROP CONSTRAINT [ClientAccount_FK01]
ALTER TABLE [dbo].[ClientAccount]  WITH CHECK ADD  CONSTRAINT [ClientAccountClientID_FK00] FOREIGN KEY([ClientID])
REFERENCES [dbo].[Client] ([ClientID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[ClientAccount] CHECK CONSTRAINT [ClientAccountClientID_FK00]
GO

DROP TRIGGER [T_ClientContacts_ITrig]
DROP TRIGGER [T_ClientContacts_UTrig]
ALTER TABLE [dbo].[ClientContacts] DROP CONSTRAINT [ClientContacts_FK00]
ALTER TABLE [dbo].[ClientContacts]  WITH CHECK ADD  CONSTRAINT [ClientContactsClientID_FK00] FOREIGN KEY([ClientID])
REFERENCES [dbo].[Client] ([ClientID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[ClientContacts] CHECK CONSTRAINT [ClientContactsClientID_FK00]
GO

DROP TRIGGER [T_ClientDocuments_ITrig]
DROP TRIGGER [T_ClientDocuments_UTrig]
ALTER TABLE [dbo].[ClientDocuments] DROP CONSTRAINT [ClientDocuments_FK00]
ALTER TABLE [dbo].[ClientDocuments]  WITH CHECK ADD  CONSTRAINT [ClientDocumentsClientID_FK00] FOREIGN KEY([ClientID])
REFERENCES [dbo].[Client] ([ClientID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[ClientDocuments] CHECK CONSTRAINT [ClientDocumentsClientID_FK00]
GO

DROP TRIGGER [T_ClientNotes_ITrig]
DROP TRIGGER [T_ClientNotes_UTrig]
ALTER TABLE [dbo].[ClientNotes] DROP CONSTRAINT [ClientNotes_FK00]
ALTER TABLE [dbo].[ClientNotes]  WITH CHECK ADD  CONSTRAINT [ClientNotesClientID_FK00] FOREIGN KEY([ClientID])
REFERENCES [dbo].[Client] ([ClientID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[ClientNotes] CHECK CONSTRAINT [ClientNotesClientID_FK00]
GO

DROP TRIGGER [T_ClientPhoto_ITrig]
DROP TRIGGER [T_ClientPhoto_UTrig]
ALTER TABLE [dbo].[ClientPhoto] DROP CONSTRAINT [ClientPhoto_FK00]
ALTER TABLE [dbo].[ClientPhoto]  WITH CHECK ADD  CONSTRAINT [ClientPhotoClientID_FK00] FOREIGN KEY([ClientID])
REFERENCES [dbo].[Client] ([ClientID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[ClientPhoto] CHECK CONSTRAINT [ClientPhotoClientID_FK00]
GO

ALTER TABLE [dbo].[Events]  WITH CHECK ADD  CONSTRAINT [EventsClientID_FK00] FOREIGN KEY([ClientID])
REFERENCES [dbo].[Client] ([ClientID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[Events] CHECK CONSTRAINT [EventsClientID_FK00]
GO

DROP TRIGGER [T_Housing_ITrig]
DROP TRIGGER [T_Housing_UTrig]
ALTER TABLE [dbo].[Housing] DROP CONSTRAINT [Housing_FK00]
ALTER TABLE [dbo].[Housing]  WITH CHECK ADD  CONSTRAINT [HousingClientID_FK00] FOREIGN KEY([ClientID])
REFERENCES [dbo].[Client] ([ClientID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[Housing] CHECK CONSTRAINT [HousingClientID_FK00]
GO

ALTER TABLE [dbo].[Impairments] DROP CONSTRAINT [Impairments_FK02]
ALTER TABLE [dbo].[Impairments]  WITH CHECK ADD  CONSTRAINT [ImpairmentsClientID_FK00] FOREIGN KEY([ClientID])
REFERENCES [dbo].[Client] ([ClientID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[Impairments] CHECK CONSTRAINT [ImpairmentsClientID_FK00]
GO

DROP TRIGGER [T_Income_ITrig]
DROP TRIGGER [T_Income_UTrig]
ALTER TABLE [dbo].[Income] DROP CONSTRAINT [Income_FK00]
ALTER TABLE [dbo].[Income]  WITH CHECK ADD  CONSTRAINT [IncomeClientID_FK00] FOREIGN KEY([ClientID])
REFERENCES [dbo].[Client] ([ClientID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[Income] CHECK CONSTRAINT [IncomeClientID_FK00]
GO

DROP TRIGGER [T_SchedDeposit_ITrig]
DROP TRIGGER [T_SchedDeposit_UTrig]
ALTER TABLE [dbo].[SchedDeposit] DROP CONSTRAINT [SchedDeposit_FK00]
ALTER TABLE [dbo].[SchedDeposit]  WITH CHECK ADD  CONSTRAINT [SchedDepositClientID_FK00] FOREIGN KEY([ClientID])
REFERENCES [dbo].[Client] ([ClientID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[SchedDeposit] CHECK CONSTRAINT [SchedDepositClientID_FK00]
GO

ALTER TABLE [dbo].[SchedTransfer] DROP CONSTRAINT [SchedTransfer_FK00]
ALTER TABLE [dbo].[SchedTransfer]  WITH CHECK ADD  CONSTRAINT [SchedTransferFromClientID_FK00] FOREIGN KEY([FromClientID])
REFERENCES [dbo].[Client] ([ClientId])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[SchedTransfer] CHECK CONSTRAINT [SchedTransferFromClientID_FK00]
GO

ALTER TABLE [dbo].[SchedTransfer]  WITH CHECK ADD  CONSTRAINT [SchedTransferToClientID_FK00] FOREIGN KEY([ToClientID])
REFERENCES [dbo].[Client] ([ClientId])
GO
ALTER TABLE [dbo].[SchedTransfer] CHECK CONSTRAINT [SchedTransferToClientID_FK00]
GO

DROP TRIGGER [T_Transaction_ITrig]
DROP TRIGGER [T_Transaction_UTrig]
ALTER TABLE [dbo].[Transaction] DROP CONSTRAINT [Transaction_FK01]
ALTER TABLE [dbo].[Transaction]  WITH CHECK ADD  CONSTRAINT [TransactionClientID_FK00] FOREIGN KEY([ClientID])
REFERENCES [dbo].[Client] ([ClientID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[Transaction] CHECK CONSTRAINT [TransactionClientID_FK00]
GO

ALTER TABLE [dbo].[ADCScores] DROP CONSTRAINT [ADCScores_FK01]
ALTER TABLE [dbo].[ADCScores]  WITH CHECK ADD  CONSTRAINT [ADCScoresClientID_FK00] FOREIGN KEY([ClientID])
REFERENCES [dbo].[Client] ([ClientID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[ADCScores] CHECK CONSTRAINT [ADCScoresClientID_FK00]
GO

ALTER TABLE [dbo].[ADCCategoriesScore] DROP CONSTRAINT [ADCCategoriesScore_FK03]
ALTER TABLE [dbo].[ADCCategoriesScore]  WITH CHECK ADD  CONSTRAINT [ADCCategoriesScoreClientID_FK00] FOREIGN KEY([ClientID])
REFERENCES [dbo].[Client] ([ClientID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[ADCCategoriesScore] CHECK CONSTRAINT [ADCCategoriesScoreClientID_FK00]
GO

DROP TRIGGER [T_ClaimNum_ITrig]
DROP TRIGGER [T_ClaimNum_UTrig]
ALTER TABLE [dbo].[ClaimNum] DROP CONSTRAINT [ClaimNum_FK00]
ALTER TABLE [dbo].[ClaimNum]  WITH CHECK ADD  CONSTRAINT [ClaimNumClientID_FK00] FOREIGN KEY([ClientID])
REFERENCES [dbo].[Client] ([ClientID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[ClaimNum] CHECK CONSTRAINT [ClaimNumClientID_FK00]
GO

-- SupportType - Update and Delete
DROP TRIGGER [T_SupportType_UTrig]
DROP TRIGGER [T_SupportType_DTrig]

ALTER TABLE [dbo].[Client]  WITH CHECK ADD  CONSTRAINT [ClientSupportType_FK00] FOREIGN KEY([SupportType])
REFERENCES [dbo].[SupportType] ([SupportType])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[Client] CHECK CONSTRAINT [ClientSupportType_FK00]
GO

ALTER TABLE [dbo].[UserSupportType]  WITH CHECK ADD  CONSTRAINT [UsertSupportTypeSupportType_FK00] FOREIGN KEY([SupportType])
REFERENCES [dbo].[SupportType] ([SupportType])
ON DELETE CASCADE
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[UserSupportType] CHECK CONSTRAINT [UsertSupportTypeSupportType_FK00]
GO

-- ClientType - Update and Delete
DROP TRIGGER [T_ClientType_UTrig]
DROP TRIGGER [T_ClientType_DTrig]

ALTER TABLE [dbo].[Client] DROP CONSTRAINT [Client_FK05]
ALTER TABLE [dbo].[Client]  WITH CHECK ADD  CONSTRAINT [ClientClientType_FK00] FOREIGN KEY([ClientType])
REFERENCES [dbo].[ClientType] ([ClientType])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[Client] CHECK CONSTRAINT [ClientClientType_FK00]
GO

ALTER TABLE [dbo].[UserClientType]  WITH CHECK ADD  CONSTRAINT [UsertClientTypeClientType_FK00] FOREIGN KEY([ClientType])
REFERENCES [dbo].[ClientType] ([ClientType])
ON DELETE CASCADE
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[UserClientType] CHECK CONSTRAINT [UsertClientTypeClientType_FK00]
GO

-- ClientContactType - Update
DROP TRIGGER [T_ClientContactTypeList_UTrig]
DROP TRIGGER [T_ClientContactTypeList_DTrig]

ALTER TABLE [dbo].[ClientContacts] DROP CONSTRAINT [ClientContacts_FK01]
ALTER TABLE [dbo].[ClientContacts]  WITH CHECK ADD  CONSTRAINT [ClientContactsContactType_FK00] FOREIGN KEY([ContactType])
REFERENCES [dbo].[ClientContactTypeList] ([ClientContactType])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[ClientContacts] CHECK CONSTRAINT [ClientContactsContactType_FK00]
GO

-- ContactType - Update
DROP TRIGGER [T_ContactTypeList_UTrig]
DROP TRIGGER [T_ContactTypeList_DTrig]

ALTER TABLE [dbo].[CaseNotes] DROP CONSTRAINT [CaseNotes_FK01]
ALTER TABLE [dbo].[CaseNotes]  WITH CHECK ADD  CONSTRAINT [CaseNotesContactType_FK00] FOREIGN KEY([ContactType])
REFERENCES [dbo].[ContactTypeList] ([ContactType])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[CaseNotes] CHECK CONSTRAINT [CaseNotesContactType_FK00]
GO

-- County - Update
DROP TRIGGER [T_County_UTrig]
DROP TRIGGER [T_County_DTrig]

ALTER TABLE [dbo].[Client]  WITH CHECK ADD  CONSTRAINT [ClientCounty_FK00] FOREIGN KEY([County])
REFERENCES [dbo].[County] ([County])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[Client] CHECK CONSTRAINT [ClientCounty_FK00]
GO

-- Housing Type - Update
DROP TRIGGER [T_HousingTypeList_UTrig]
DROP TRIGGER [T_HousingTypeList_DTrig]

ALTER TABLE [dbo].[Housing] DROP CONSTRAINT [Housing_FK01]
ALTER TABLE [dbo].[Housing]  WITH CHECK ADD  CONSTRAINT [HousingHousingType_FK00] FOREIGN KEY([HousingType])
REFERENCES [dbo].[HousingTypeList] ([HousingType])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[Housing] CHECK CONSTRAINT [HousingHousingType_FK00]
GO

-- Race - Update
DROP TRIGGER [T_RaceList_UTrig]
DROP TRIGGER [T_RaceList_DTrig]

ALTER TABLE [dbo].[Client] DROP CONSTRAINT [Client_FK03]
ALTER TABLE [dbo].[Client]  WITH CHECK ADD  CONSTRAINT [ClientRace_FK00] FOREIGN KEY([Race])
REFERENCES [dbo].[RaceList] ([RaceDescription])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[Client] CHECK CONSTRAINT [ClientRace_FK00]
GO

-- Referral Source - Update
DROP TRIGGER [T_ReferralSourceList_UTrig]
DROP TRIGGER [T_ReferralSourceList_DTrig]

ALTER TABLE [dbo].[Client] DROP CONSTRAINT [Client_FK07]
ALTER TABLE [dbo].[Client]  WITH CHECK ADD  CONSTRAINT [ClientReferralSource_FK00] FOREIGN KEY([ReferralSource])
REFERENCES [dbo].[ReferralSourceList] ([ReferralSource])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[Client] CHECK CONSTRAINT [ClientReferralSource_FK00]
GO

-- Termination Reason - Update
DROP TRIGGER [T_TerminationReasonList_UTrig]
DROP TRIGGER [T_TerminationReasonList_DTrig]

ALTER TABLE [dbo].[Client] DROP CONSTRAINT [Client_FK08]
ALTER TABLE [dbo].[Client]  WITH CHECK ADD  CONSTRAINT [ClientTerminationReason_FK00] FOREIGN KEY([TermReason])
REFERENCES [dbo].[TerminationReasonList] ([TerminationReason])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[Client] CHECK CONSTRAINT [ClientTerminationReason_FK00]
GO

-- County District - Update
DROP TRIGGER [T_CountyDistrict_UTrig]
DROP TRIGGER [T_CountyDistrict_DTrig]

ALTER TABLE [dbo].[Client] DROP CONSTRAINT [Client_FK00]
ALTER TABLE [dbo].[Client]  WITH CHECK ADD  CONSTRAINT [ClientCountyDistrict_FK00] FOREIGN KEY([CountyDistrict])
REFERENCES [dbo].[CountyDistrict] ([CountyID])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[Client] CHECK CONSTRAINT [ClientCountyDistrict_FK00]
GO

-- Legislative District - Update
DROP TRIGGER [T_LegislativeDistrict_UTrig]
DROP TRIGGER [T_LegislativeDistrict_DTrig]

ALTER TABLE [dbo].[Client] DROP CONSTRAINT [Client_FK01]
ALTER TABLE [dbo].[Client]  WITH CHECK ADD  CONSTRAINT [ClientLegislativeDistrict_FK00] FOREIGN KEY([LegislativeDistrict])
REFERENCES [dbo].[LegislativeDistrict] ([LegID])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[Client] CHECK CONSTRAINT [ClientLegislativeDistrict_FK00]
GO

-- Ward Number - Update
DROP TRIGGER [T_WardNumber_UTrig]
DROP TRIGGER [T_WardNumber_DTrig]

ALTER TABLE [dbo].[Client] DROP CONSTRAINT [Client_FK09]
ALTER TABLE [dbo].[Client]  WITH CHECK ADD  CONSTRAINT [ClientWardNumber_FK00] FOREIGN KEY([WardNumber])
REFERENCES [dbo].[WardNumber] ([WardID])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[Client] CHECK CONSTRAINT [ClientWardNumber_FK00]
GO

-- Marital Status - Update
DROP TRIGGER [T_MaritalStatusList_UTrig]
DROP TRIGGER [T_MaritalStatusList_DTrig]

ALTER TABLE [dbo].[Client] DROP CONSTRAINT [Client_FK02]
ALTER TABLE [dbo].[Client]  WITH CHECK ADD  CONSTRAINT [ClientMaritalStatus_FK00] FOREIGN KEY([MaritalStatus])
REFERENCES [dbo].[MaritalStatusList] ([MaritalStatusType])
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[Client] CHECK CONSTRAINT [ClientMaritalStatus_FK00]
GO

-- User - Update and Delete
DROP TRIGGER [T_User_UTrig]
DROP TRIGGER [T_User_DTrig]
DROP TRIGGER [T_UserSecurity_UTrig]
DROP TRIGGER [T_UserSecurity_ITrig]

ALTER TABLE [dbo].[UserSecurity] DROP CONSTRAINT [UserSecurity_FK00]
ALTER TABLE [dbo].[UserSecurity]  WITH CHECK ADD  CONSTRAINT [UserSecurityUserID_FK00] FOREIGN KEY([UserID])
REFERENCES [dbo].[User] ([UserID])
ON DELETE CASCADE
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[UserSecurity] CHECK CONSTRAINT [UserSecurityUserID_FK00]
GO

ALTER TABLE [dbo].[UserSupportType]  WITH CHECK ADD  CONSTRAINT [UserSupportTypeUserID_FK00] FOREIGN KEY([UserID])
REFERENCES [dbo].[User] ([UserID])
ON DELETE CASCADE
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[UserSupportType] CHECK CONSTRAINT [UserSupportTypeUserID_FK00]
GO

ALTER TABLE [dbo].[UserClientType]  WITH CHECK ADD  CONSTRAINT [UserClientTypeUserID_FK00] FOREIGN KEY([UserID])
REFERENCES [dbo].[User] ([UserID])
ON DELETE CASCADE
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[UserClientType] CHECK CONSTRAINT [UserClientTypeUserID_FK00]
GO

ALTER TABLE [dbo].[UserSchedule] DROP CONSTRAINT [UserSchedule_FK00]
ALTER TABLE [dbo].[UserSchedule]  WITH CHECK ADD  CONSTRAINT [UserScheduleUserID_FK00] FOREIGN KEY([UserID])
REFERENCES [dbo].[User] ([UserID])
ON DELETE CASCADE
ON UPDATE CASCADE
GO
ALTER TABLE [dbo].[UserSchedule] CHECK CONSTRAINT [UserScheduleUserID_FK00]
GO

-- Account Manager
ALTER TABLE [dbo].[Client] DROP CONSTRAINT [Client_FK04]
ALTER TABLE [dbo].[Client]  WITH NOCHECK ADD  CONSTRAINT [ClientAcctMgrID_FK04] FOREIGN KEY([AcctMgrId])
REFERENCES [dbo].[AcctMgr] ([AcctMgrId])
GO

ALTER TABLE [dbo].[Client] NOCHECK CONSTRAINT [ClientAcctMgrID_FK04]
GO

-- Delete error messages more than 3 years old
DELETE FROM ErrorMessages WHERE Error_Date < Dateadd(yyyy, -3, GETDATE())
GO

-- Update version
Update VersionDataSQL Set CurrentVersionNum = 607
Go

